@@ -65,13 +65,16 @@ public:
     // buildFromSettings assumes a settings object in the object context
     virtual void writeToSettings(QSettings &settings) const override;
     virtual void buildFromSettings(const QSettings &settings) override;
-    QString settingsGroupName() const;
     virtual void validateToken() override;
 
+    bool hasFollowRequests() const override;
+    Q_INVOKABLE void checkForFollowRequests() override;
+
 private:
     bool m_ignoreSslErrors = false;
     QNetworkAccessManager *m_qnam;
     QMap<QString, QWebSocket *> m_websockets;
+    bool m_hasFollowRequests = false;
 
     // common parts for all HTTP request
     QNetworkRequest makeRequest(const QUrl &url, bool authenticated) const;
